/*
	Central list of function IDs
	The core and core plugins use these from a single, central hash
	This list is used to cpp-generate the F_* constants in enum pcb_function_id_t
*/

/* layer purpose */
action_entry(user)
action_entry(fab)
action_entry(assy)
action_entry(csect)
action_entry(pdrill)
action_entry(udrill)
action_entry(proute)
action_entry(uroute)
action_entry(ucut)
action_entry(uvcut)

/* Keywords for actions */
action_entry(Add)
action_entry(AddSelected)
action_entry(AddRats)
action_entry(All)
action_entry(AllConnections)
action_entry(AllRats)
action_entry(AllUnusedPins)
action_entry(AutoLen)
action_entry(Block)
action_entry(Buffer)
action_entry(Cancel)
action_entry(Center)
action_entry(Check)
action_entry(Clear)
action_entry(ClearAndRedraw)
action_entry(ClearList)
action_entry(Close)
action_entry(CloseHole)
action_entry(Connection)
action_entry(Convert)
action_entry(ConvertSubc)
action_entry(CycleClip)
action_entry(CycleCrosshair)
action_entry(DeleteRats)
action_entry(Done)
action_entry(Drag)
action_entry(DrillReport)
action_entry(Element)
action_entry(ElementConnections)
action_entry(ElementToBuffer)
action_entry(Escape)
action_entry(Eq)
action_entry(Export)
action_entry(Find)
action_entry(FlipElement)
action_entry(Found)
action_entry(FoundPins)
action_entry(Footprint)
action_entry(FootprintToBuffer)
action_entry(ForceThaw)
action_entry(Freeze)
action_entry(GetSource)
action_entry(Grid)
action_entry(Hash)
action_entry(Invert)
action_entry(Layer)
action_entry(Layout)
action_entry(LayoutAs)
action_entry(LayoutToBuffer)
action_entry(Lihata)
action_entry(Line)
action_entry(LineSize)
action_entry(LoadAll)
action_entry(Loose)
action_entry(Merge)
action_entry(Mirror)
action_entry(MoveSelected)
action_entry(Native)
action_entry(Netlist)
action_entry(Need)
action_entry(Next)
action_entry(NoAutoLen)
action_entry(Normalize)
action_entry(Notify)
action_entry(NoAllRats)
action_entry(NoRats)
action_entry(Object)
action_entry(Off)
action_entry(On)
action_entry(Pan)
action_entry(PasteBuffer)
action_entry(PinOrPadName)
action_entry(Pinout)
action_entry(Pop)
action_entry(Press)
action_entry(PreviousPoint)
action_entry(Prev)
action_entry(Push)
action_entry(Rats)
action_entry(RatsNest)
action_entry(Redraw)
action_entry(Refdes)
action_entry(Release)
action_entry(Revert)
action_entry(RemoveSelected)
action_entry(Rename)
action_entry(Report)
action_entry(ResetLayerObjects)
action_entry(ResetLinesAndPolygons)
action_entry(ResetPadstacks)
action_entry(ResetPinsViasAndPads)
action_entry(Resize)
action_entry(Restore)
action_entry(Ripup)
action_entry(Rotate)
action_entry(Save)
action_entry(SaveAll)
action_entry(Select)
action_entry(Selected)
action_entry(SelectedArcs)
action_entry(SelectedElements)
action_entry(SelectedLines)
action_entry(SelectedNames)
action_entry(SelectedObjects)
action_entry(SelectedPads)
action_entry(SelectedPins)
action_entry(SelectedPadstacks)
action_entry(SelectedTexts)
action_entry(SelectedVias)
action_entry(SelectedRats)
action_entry(Sides)
action_entry(Sort)
action_entry(Start)
action_entry(Stroke)
action_entry(Style)
action_entry(Subc)
action_entry(Subcircuit)
action_entry(SubcConnections)
action_entry(SubcToBuffer)
action_entry(SubcID)
action_entry(Swap)
action_entry(TermID)
action_entry(Text)
action_entry(TextScale)
action_entry(Thaw)
action_entry(ToLayout)
action_entry(ToggleAllDirections)
action_entry(ToggleAutoDRC)
action_entry(ToggleClearLine)
action_entry(ToggleFullPoly)
action_entry(ToggleGrid)
action_entry(ToggleHideNames)
action_entry(ToggleMinCut)
action_entry(ToggleMask)
action_entry(TogglePaste)
action_entry(ToggleName)
action_entry(ToggleObject)
action_entry(ToggleShowDRC)
action_entry(ToggleLiveRoute)
action_entry(ToggleRubberBandMode)
action_entry(ToggleStartDirection)
action_entry(ToggleSnapPin)
action_entry(ToggleSnapOffGridLine)
action_entry(ToggleHighlightOnPoint)
action_entry(ToggleThindraw)
action_entry(ToggleLockNames)
action_entry(ToggleOnlyNames)
action_entry(ToggleThindrawPoly)
action_entry(ToggleOrthoMove)
action_entry(ToggleLocalRef)
action_entry(ToggleCheckPlanes)
action_entry(ToggleUniqueNames)
action_entry(ToggleStroke)
action_entry(Transparent)
action_entry(Unselect)
action_entry(UnFreeze)
action_entry(Via)
action_entry(Warp)
action_entry(Zoom)

